@@ -1,6 +1,6 @@
 .onAttach <- function(libname, pkgname) {
   msg <- paste(
     paste("kissmig", utils::packageVersion("kissmig")),
-    "- major new feature: speedup through parallel processing")
+    "- new in v2.0: speedup through parallel processing")
   packageStartupMessage(msg)
 }
